==> docx4j-openxml-objects-pml-8.0.0-sources.jar: org/pptx4j/pml/CTPhotoAlbum.java <==
/*
 *  Copyright 2010-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.pptx4j.pml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for CT_PhotoAlbum complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_PhotoAlbum">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="extLst" type="{http://schemas.openxmlformats.org/presentationml/2006/main}CT_ExtensionList" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="bw" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="showCaptions" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       &lt;attribute name="layout" type="{http://schemas.openxmlformats.org/presentationml/2006/main}ST_PhotoAlbumLayout" default="fitToSlide" />
 *       &lt;attribute name="frame" type="{http://schemas.openxmlformats.org/presentationml/2006/main}ST_PhotoAlbumFrameShape" default="frameStyle1" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_PhotoAlbum", propOrder = {
    "extLst"
})
public class CTPhotoAlbum {

    protected CTExtensionList extLst;
    @XmlAttribute(name = "bw")
    protected Boolean bw;
    @XmlAttribute(name = "showCaptions")
    protected Boolean showCaptions;
    @XmlAttribute(name = "layout")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String layout;
    @XmlAttribute(name = "frame")
    protected STPhotoAlbumFrameShape frame;

    /**
     * Gets the value of the extLst property.
     * 
     * @return
     *     possible object is
     *     {@link CTExtensionList }
     *     
     */
    public CTExtensionList getExtLst() {
        return extLst;
    }

    /**
     * Sets the value of the extLst property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTExtensionList }
     *     
     */
    public void setExtLst(CTExtensionList value) {
        this.extLst = value;
    }

    /**
     * Gets the value of the bw property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isBw() {
        if (bw == null) {
            return false;
        } else {
            return bw;
        }
    }

    /**
     * Sets the value of the bw property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setBw(Boolean value) {
        this.bw = value;
    }

    /**
     * Gets the value of the showCaptions property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCaptions() {
        if (showCaptions == null) {
            return false;
        } else {
            return showCaptions;
        }
    }

    /**
     * Sets the value of the showCaptions property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCaptions(Boolean value) {
        this.showCaptions = value;
    }

    /**
     * Gets the value of the layout property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLayout() {
        if (layout == null) {
            return "fitToSlide";
        } else {
            return layout;
        }
    }

    /**
     * Sets the value of the layout property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLayout(String value) {
        this.layout = value;
    }

    /**
     * Gets the value of the frame property.
     * 
     * @return
     *     possible object is
     *     {@link STPhotoAlbumFrameShape }
     *     
     */
    public STPhotoAlbumFrameShape getFrame() {
        if (frame == null) {
            return STPhotoAlbumFrameShape.FRAME_STYLE_1;
        } else {
            return frame;
        }
    }

    /**
     * Sets the value of the frame property.
     * 
     * @param value
     *     allowed object is
     *     {@link STPhotoAlbumFrameShape }
     *     
     */
    public void setFrame(STPhotoAlbumFrameShape value) {
        this.frame = value;
    }

}

==> docx4j-openxml-objects-pml-8.1.1-sources.jar: org/pptx4j/pml/CTPhotoAlbum.java <==
/*
 *  Copyright 2010-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.pptx4j.pml;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_PhotoAlbum complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_PhotoAlbum"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="extLst" type="{http://schemas.openxmlformats.org/presentationml/2006/main}CT_ExtensionList" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="bw" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="showCaptions" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="layout" type="{http://schemas.openxmlformats.org/presentationml/2006/main}ST_PhotoAlbumLayout" default="fitToSlide" /&gt;
 *       &lt;attribute name="frame" type="{http://schemas.openxmlformats.org/presentationml/2006/main}ST_PhotoAlbumFrameShape" default="frameStyle1" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_PhotoAlbum", propOrder = {
    "extLst"
})
public class CTPhotoAlbum implements Child
{

    protected CTExtensionList extLst;
    @XmlAttribute(name = "bw")
    protected Boolean bw;
    @XmlAttribute(name = "showCaptions")
    protected Boolean showCaptions;
    @XmlAttribute(name = "layout")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String layout;
    @XmlAttribute(name = "frame")
    protected STPhotoAlbumFrameShape frame;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the extLst property.
     * 
     * @return
     *     possible object is
     *     {@link CTExtensionList }
     *     
     */
    public CTExtensionList getExtLst() {
        return extLst;
    }

    /**
     * Sets the value of the extLst property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTExtensionList }
     *     
     */
    public void setExtLst(CTExtensionList value) {
        this.extLst = value;
    }

    /**
     * Gets the value of the bw property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isBw() {
        if (bw == null) {
            return false;
        } else {
            return bw;
        }
    }

    /**
     * Sets the value of the bw property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setBw(Boolean value) {
        this.bw = value;
    }

    /**
     * Gets the value of the showCaptions property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCaptions() {
        if (showCaptions == null) {
            return false;
        } else {
            return showCaptions;
        }
    }

    /**
     * Sets the value of the showCaptions property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCaptions(Boolean value) {
        this.showCaptions = value;
    }

    /**
     * Gets the value of the layout property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLayout() {
        if (layout == null) {
            return "fitToSlide";
        } else {
            return layout;
        }
    }

    /**
     * Sets the value of the layout property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLayout(String value) {
        this.layout = value;
    }

    /**
     * Gets the value of the frame property.
     * 
     * @return
     *     possible object is
     *     {@link STPhotoAlbumFrameShape }
     *     
     */
    public STPhotoAlbumFrameShape getFrame() {
        if (frame == null) {
            return STPhotoAlbumFrameShape.FRAME_STYLE_1;
        } else {
            return frame;
        }
    }

    /**
     * Sets the value of the frame property.
     * 
     * @param value
     *     allowed object is
     *     {@link STPhotoAlbumFrameShape }
     *     
     */
    public void setFrame(STPhotoAlbumFrameShape value) {
        this.frame = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
